interface DomOptions extends Record<string, unknown> {
    /**
     * @default 0
     */
    "theme-id"?: string | number;
    "slug-hash"?: string;
    user?: string;
    name?: string;
    href?: string;
    /**
     * @description one of or a set of "html" | "css" | "js" | "result"
     * @default "result"
     */
    "default-tab"?: string;
    /**
     * @default 300
     */
    height?: number | string;
    animations?: "run" | "stop-after-5";
    /**
     * @default none
     */
    border?: "none" | "thin" | "thick";
    /**
     * @default #000000
     */
    "border-color"?: string;
    /**
     * @default #3d3d3e
     */
    "tab-bar-color"?: string;
    /**
     * @default #76daff
     */
    "tab-link-color"?: string;
    /**
     * @default #cccccc
     */
    "active-tab-color"?: string;
    /**
     * @default #000000
     */
    "active-link-color"?: string;
    /**
     * @default #ffffff
     */
    "link-logo-color"?: string;
    class?: string;
    "custom-css-url"?: string;
    preview?: "true" | "none";
    /**
     * @default 1
     */
    zoom?: 1 | 0.5 | 0.25;
    token?: string;
    "pen-title"?: string;
    /**
     * @deprecated use "animations" instead
     */
    safe?: "true";
    /**
     * @deprecated use "default-tab" instead
     */
    type?: string;
}
interface PrefillOptions {
    title?: string;
    description?: string;
    head?: string;
    tags?: string | string[];
    html_classes?: string | string[];
    stylesheets?: string | string[];
    scripts?: string | string[];
}
interface APIOptions extends DomOptions {
    /** @private */
    data?: string;
    prefill?: PrefillOptions;
    /**
     * @default "false"
     */
    editable?: "true" | "false";
}

declare const renderCodePen: (selector: string | HTMLElement, options: APIOptions) => void;

declare const loadCodePens: (selector?: string) => void;

export { APIOptions, DomOptions, PrefillOptions, loadCodePens, renderCodePen };
//# sourceMappingURL=index.d.ts.map
